document.addEventListener('DOMContentLoaded', () => {
    const toggleSwitch = document.getElementById('toggleSwitch');
    const exportBtn = document.getElementById('exportBtn');

    // Check plugin state and set the checkbox accordingly
    chrome.storage.local.get('active', (result) => {
        toggleSwitch.checked = result.active !== false;  // default to active if not set
    });

    // Toggle plugin state when checkbox is changed
    toggleSwitch.addEventListener('change', () => {
        chrome.storage.local.set({ 'active': toggleSwitch.checked });
    });

	// Convert data to CSV format
	function convertToCSV(objArray) {
		const array = typeof objArray !== 'object' ? JSON.parse(objArray) : objArray;
		let str = 'Email,URL,Title\n';

		for (let i = 0; i < array.length; i++) {
			let line = '';
			for (let index in array[i]) {
				if (line !== '') line += ',';

				line += '"' + array[i][index] + '"';
			}
			str += line + '\n';
		}
		return str;
	}


	// Export data
	exportBtn.addEventListener('click', () => {
		chrome.storage.local.get('storedData', (result) => {
			const data = result.storedData || [];
			const csvData = convertToCSV(data);
			const blob = new Blob([csvData], { type: 'text/csv' });
			const url = URL.createObjectURL(blob);
			const a = document.createElement('a');
			a.href = url;
			a.download = 'emails.csv';
			a.click();
		});
	});

	document.getElementById("clearData").addEventListener("click", function() {
		// 
		chrome.storage.local.clear(() => {
			alert("Data cleared successfully!");
		});
	});



    // Display stored emails
    chrome.storage.local.get(['storedData'], (result) => {
        const emailList = document.getElementById('emailList');
        const data = result.storedData || [];
        data.forEach(item => {
            const li = document.createElement('li');
            li.textContent = `${item.email}`;
            emailList.appendChild(li);
        });
    });
});
